@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``adduser`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -35,6 +38,19 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_adduser(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl adduser`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by
+        ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "adduser", help="Add a new matrix user"
     )
@@ -70,60 +86,64 @@ def adduser(arg: Namespace) -> int:
     Depending on the ``--ansible`` switch it runs the ``adduser`` command
     via ansible or the API
 
-    :param arg:       The ``Namespace`` object of argparse's ``arse_args()``
-    :return:          None
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
     """
 
-    with TOML() as toml:
-        with API(
-            toml.get(("API", "Domain")), toml.get(("API", "Token"))
-        ) as api:
+    toml: TOML = TOML()
+    api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
 
-            while True:
-                passwd_generated: bool = False
+    while True:
+        passwd_generated: bool = False
 
-                if arg.passwd is None:
-                    arg.passwd = ask_password()
+        if arg.passwd is None:
+            arg.passwd = ask_password()
 
-                if arg.passwd == "":
-                    arg.passwd = gen_password()
-                    passwd_generated = True
+        if arg.passwd == "":
+            arg.passwd = gen_password()
+            passwd_generated = True
 
-                print(f"Username: {arg.user}")
+        print(f"Username: {arg.user}")
 
-                if passwd_generated:
-                    print(f"Password (generated): {arg.passwd}")
-                else:
-                    print("Password: **HIDDEN**")
-                print(f"Admin:    {'yes' if arg.admin else 'no'}")
+        if passwd_generated:
+            print(f"Password (generated): {arg.passwd}")
+        else:
+            print("Password: **HIDDEN**")
+        print(f"Admin:    {'yes' if arg.admin else 'no'}")
 
-                answer = ask_question()
+        answer = ask_question()
 
-                if answer:
-                    break
-                arg.passwd = None
+        if answer:
+            break
+        arg.passwd = None
 
-            if arg.ansible:
-                ansible_run(
-                    playbook=toml.get(("ANSIBLE", "Playbook")),
-                    tags="register-user",
-                    extra_vars={
-                        "username": arg.user,
-                        "password": arg.passwd,
-                        "admin": "yes" if arg.admin else "no",
-                    },
-                )
-            else:
-                try:
-                    api.url.path = (
-                        f"users/@{arg.user}:{toml.get(('API','Domain'))}"
-                    )
-                    api.method = "PUT"
-                    api.request({"password": arg.passwd, "admin": arg.admin})
-                except InternalResponseError:
-                    error("The User was not added.")
+    if arg.ansible:
+        ansible_run(
+            playbook=toml.get("ANSIBLE", "Playbook"),
+            tags="register-user",
+            extra_vars={
+                "username": arg.user,
+                "password": arg.passwd,
+                "admin": "yes" if arg.admin else "no",
+            },
+        )
+    else:
+        try:
+            api.url.path = f"users/@{arg.user}:{toml.get('API','Domain')}"
+            api.method = "PUT"
+            api.request({"password": arg.passwd, "admin": arg.admin})
+        except InternalResponseError:
+            error("The User was not added.")
 
-        return 0
+    return 0
 
 
 # vim: set ft=python :
