@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``deploy`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -30,6 +33,19 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_deploy(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl deploy`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by
+        ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "deploy", help="Provision and deploy"
     )
@@ -37,15 +53,27 @@ def subparser_deploy(subparsers: SubParsersAction) -> None:
 
 
 def deploy(_: Namespace) -> int:
-    """Deploy the ansible playbook."""
-    debug("deploy")
-    with TOML() as toml:
-        ansible_run(
-            playbook=toml.get(("ANSIBLE", "Playbook")),
-            tags="setup-all",
-        )
+    """Deploy the ansible playbook.
 
-        return 0
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
+    """
+    debug("deploy")
+    toml: TOML = TOML()
+    ansible_run(
+        playbook=toml.get("ANSIBLE", "Playbook"),
+        tags="setup-all",
+    )
+
+    return 0
 
 
 # vim: set ft=python :
