@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``maintenance`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -30,6 +33,19 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_maintenance(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl maintenance`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by
+        ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "maintenance", help="Run maintenance tasks"
     )
@@ -37,13 +53,28 @@ def subparser_maintenance(subparsers: SubParsersAction) -> None:
 
 
 def maintenance(_: Namespace) -> int:
+    """Run the maintenance procedure of the ansible playbook.
+
+    Parameters
+    ----------
+    _ : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``.
+        (In this case unused, but necessary because of the structure of the
+        program).
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
+    """
     debug("maintenance")
 
-    with TOML() as toml:
-        ansible_run(
-            playbook=toml.get(("ANSIBLE", "Playbook")),
-            tags="run-postgres-vacuum,start",
-        )
+    toml: TOML = TOML()
+    ansible_run(
+        playbook=toml.get("ANSIBLE", "Playbook"),
+        tags="run-postgres-vacuum,start",
+    )
 
     return 0
 
